@@ -1,13 +1,13 @@
 package Net::GitHub::V2::Commits;
 
-use Any::Moose;
+use Moose;
 
-our $VERSION = '0.13';
+our $VERSION = '0.06';
 our $AUTHORITY = 'cpan:FAYLAND';
 
 use URI::Escape;
 
-with 'Net::GitHub::V2::HasRepo';
+with 'Net::GitHub::V2::Role';
 
 sub branch {
     my ( $self, $branch ) = @_;
@@ -22,11 +22,6 @@ sub branch {
 sub file {
     my ( $self, $branch, $path ) = @_;
     
-    unless ( $path ) {
-        $path = $branch;
-        $branch = 'master';
-    }
-
     my $owner = $self->owner;
     my $repo  = $self->repo;
     
@@ -42,7 +37,7 @@ sub show {
     return $self->get_json_to_obj( "commits/show/$owner/$repo/$sha1", 'commit' );
 }
 
-no Any::Moose;
+no Moose;
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -56,45 +51,34 @@ Net::GitHub::V2::Commits - GitHub Commits API
 
     use Net::GitHub::V2::Commits;
 
-    my $github_commits = Net::GitHub::V2::Commits->new(
-        owner => 'fayland',            # GitHub username/organisation
-        repo  => 'perl-net-github',    # Repository name
-    );
+    my $commit = Net::GitHub::V2::Commits->new();
 
 =head1 DESCRIPTION
 
 L<http://develop.github.com/p/commits.html>
 
-See also L<Net::GitHub> for how to create a L<Net::GitHub> object with the
-appropriate attributes, then get a C<Net::GitHub::V2::Commits> object from it
-easily.
-
-
 =head1 METHODS
 
 =over 4
 
 =item branch
 
-    my $commits = $github_commits->branch(); # default as 'master'
-    my $commits = $github_commits->branch('v2');
+    my $commits = $commit->branch(); # default as 'master'
+    my $commits = $commit->branch('v2');
 
 list commits for a branch
 
-=item file($branch, $file)
+=item file
 
-    my $commits = $github_commits->file( 'master', 'lib/Net/GitHub.pm' );
-    my $commits = $github_commits->file( 'lib/Net/GitHub.pm' ); # the same as above
+    my $commits = $commit->file( 'master', 'lib/Net/GitHub.pm' );
 
-get all the commits that modified the file (default $branch to 'master')
+get all the commits that modified the file
 
 =item show
 
-    my $commit = $github_commits->show( '9bd63ae2114e3c7e4279b81ab2d8d8947ab4011d' );
+    my $co_detail = $commit->show( '0e2e9d452f807f4b7138ae707e84577c10891d0c' );
 
-get the changes introduced on a specific commit
-
-(As usual, the SHA can be abbreviated)
+get a the changes introduced on a specific commit
 
 =back
 
@@ -107,4 +91,4 @@ Fayland Lam, C<< <fayland at gmail.com> >>
 Copyright 2009 Fayland Lam, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+under the same terms as Perl itself.
\ No newline at end of file
