@@ -2,7 +2,7 @@ package Net::GitHub::V2::Users;
 
 use Moose;
 
-our $VERSION = '0.06';
+our $VERSION = '0.10';
 our $AUTHORITY = 'cpan:FAYLAND';
 
 use URI::Escape;
@@ -34,7 +34,7 @@ sub update {
         push @values, ( "values[$key]", $up{$key} );
     }
     
-    return $self->get_json_to_obj_authed( "user/$user", @values, 'user' );
+    return $self->get_json_to_obj_authed( "user/show/$user", @values, 'user' );
 }
 
 sub followers {
@@ -143,7 +143,7 @@ user searching
     my $uinfo = $user->show(); # owner in ->new
     my $uinfo = $user->show( 'nothingmuch' );
 
-get extended information on users
+get extended information on user
 
 =item update
 
@@ -154,6 +154,8 @@ get extended information on users
 
 update your users information (authentication required)
 
+possible keys: name, email, blog, company, location
+
 =item followers
 
 =item following
